diff --git a/data/interfaces/parole-settings.ui b/data/interfaces/parole-settings.ui
index 1915bfb..679346e 100644
--- a/data/interfaces/parole-settings.ui
+++ b/data/interfaces/parole-settings.ui
@@ -58,14 +58,42 @@
                             <property name="left_padding">12</property>
                             <property name="right_padding">12</property>
                             <child>
-                              <object class="GtkCheckButton" id="reset-saver">
-                                <property name="label" translatable="yes">Disable screensaver while playing movies</property>
+                              <object class="GtkVBox" id="vbox3">
                                 <property name="visible">True</property>
-                                <property name="can_focus">True</property>
-                                <property name="receives_default">False</property>
-                                <property name="use_action_appearance">False</property>
-                                <property name="draw_indicator">True</property>
-                                <signal name="toggled" handler="parole_conf_dialog_reset_saver_changed_cb" swapped="no"/>
+                                <property name="can_focus">False</property>
+                                <property name="spacing">4</property>
+                                <child>
+                                  <object class="GtkCheckButton" id="enable-xv">
+                                    <property name="label" translatable="yes">Enable Xv video output (requires a restart)</property>
+                                    <property name="use_action_appearance">False</property>
+                                    <property name="visible">True</property>
+                                    <property name="can_focus">True</property>
+                                    <property name="receives_default">False</property>
+                                    <property name="draw_indicator">True</property>
+                                    <signal name="toggled" handler="parole_conf_dialog_enable_xv_changed_cb" swapped="no"/>
+                                  </object>
+                                  <packing>
+                                    <property name="expand">True</property>
+                                    <property name="fill">True</property>
+                                    <property name="position">0</property>
+                                  </packing>
+                                </child>
+                                <child>
+                                  <object class="GtkCheckButton" id="reset-saver">
+                                    <property name="label" translatable="yes">Disable screensaver while playing movies</property>
+                                    <property name="use_action_appearance">False</property>
+                                    <property name="visible">True</property>
+                                    <property name="can_focus">True</property>
+                                    <property name="receives_default">False</property>
+                                    <property name="draw_indicator">True</property>
+                                    <signal name="toggled" handler="parole_conf_dialog_reset_saver_changed_cb" swapped="no"/>
+                                  </object>
+                                  <packing>
+                                    <property name="expand">True</property>
+                                    <property name="fill">True</property>
+                                    <property name="position">1</property>
+                                  </packing>
+                                </child>
                               </object>
                             </child>
                           </object>
diff --git a/src/parole-conf-dialog.c b/src/parole-conf-dialog.c
index 3158cb1..2912564 100644
--- a/src/parole-conf-dialog.c
+++ b/src/parole-conf-dialog.c
@@ -34,6 +34,7 @@
 #include "parole-conf.h"
 #include "parole-vis.h"
 #include "parole-subtitle-encoding.h"
+#include "parole-rc-utils.h"
 
 /*
  * GtkBuilder Callbacks
@@ -46,6 +47,9 @@ void		parole_conf_dialog_response_cb		 	(GtkDialog *dialog,
 void		parole_conf_dialog_enable_vis_changed_cb 	(GtkToggleButton *widget,
 								 ParoleConfDialog *self);
 
+void		parole_conf_dialog_enable_xv_changed_cb		(GtkToggleButton *widget,
+								 ParoleConfDialog *self);
+
 void		parole_conf_dialog_reset_saver_changed_cb	(GtkToggleButton *widget,
 								 ParoleConfDialog *self);
 
@@ -250,6 +254,12 @@ void parole_conf_dialog_vis_plugin_changed_cb (GtkComboBox *widget,  ParoleConfD
     g_free (active);
 }
 
+void parole_conf_dialog_enable_xv_changed_cb (GtkToggleButton *widget, ParoleConfDialog *self)
+{
+    gboolean enable_xv = gtk_toggle_button_get_active (widget);
+    parole_rc_write_entry_bool ("enable-xv", PAROLE_RC_GROUP_GENERAL, enable_xv);
+}
+
 void parole_conf_dialog_reset_saver_changed_cb (GtkToggleButton *widget, ParoleConfDialog *self)
 {
     g_object_set (G_OBJECT (self->priv->conf),
@@ -457,6 +467,7 @@ void parole_conf_dialog_open (ParoleConfDialog *self, GtkWidget *parent)
     GtkWidget  *dialog;
     GtkWidget  *combox;
     gboolean    with_display;
+    gboolean    enable_xv;
     gboolean    reset_saver;
     
     builder = parole_builder_new_from_string (parole_settings_ui, parole_settings_ui_length);
@@ -481,6 +492,10 @@ void parole_conf_dialog_open (ParoleConfDialog *self, GtkWidget *parent)
     parole_conf_dialog_set_defaults_general (self, builder);
     parole_conf_dialog_set_defaults_playlist (self, builder);
     
+    enable_xv = parole_rc_read_entry_bool ("enable-xv", PAROLE_RC_GROUP_GENERAL, TRUE);
+    gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (gtk_builder_get_object (builder, "enable-xv")),
+				  enable_xv);
+    
     g_object_get (G_OBJECT (self->priv->conf),
 		  "reset-saver", &reset_saver,
 		  NULL);
